Class: RubyEventStore::MCP::Tools::EventStreams
- Inherits:
-
Object
- Object
- RubyEventStore::MCP::Tools::EventStreams
- Defined in:
- lib/ruby_event_store/mcp/tools/event_streams.rb
Instance Method Summary collapse
Instance Method Details
#call(event_store, args) ⇒ Object
25 26 27 28 29 |
# File 'lib/ruby_event_store/mcp/tools/event_streams.rb', line 25 def call(event_store, args) streams = event_store.streams_of(args.fetch("event_id")) return "(no streams — event not found or not linked to any stream)" if streams.empty? format_streams(streams) end |
#name ⇒ Object
7 8 9 |
# File 'lib/ruby_event_store/mcp/tools/event_streams.rb', line 7 def name "event_streams" end |
#schema ⇒ Object
11 12 13 14 15 16 17 18 19 20 21 22 23 |
# File 'lib/ruby_event_store/mcp/tools/event_streams.rb', line 11 def schema { name: name, description: "List all streams the event has been published or linked to", inputSchema: { type: "object", properties: { event_id: { type: "string", description: "Event ID (UUID)" } }, required: ["event_id"] } } end |